pub enum ExchangePattern {
InOnly,
InOut,
}Expand description
Message exchange pattern for JMS endpoints.
InOnly: Fire-and-forget (default). The producer sends a message and does not wait for a reply.InOut: Request-reply. The producer sends a message and waits for a correlated reply on a temporary or dedicated reply destination. Not yet implemented — using this value emits a warning.
Variants