pub enum JmsTransactionMode {
None,
Session,
}Expand description
JMS transaction mode for sessions.
None: No transaction boundaries are applied. Each operation is auto-acknowledged (subject to the acknowledgement mode).Session: All send/receive operations within a session are batched into a single transaction that must be explicitly committed or rolled back. Not yet implemented — using this value emits a warning and falls back toNone.
Variants