pub struct JmsBridgePool { /* private fields */ }Implementations
Sourceimpl JmsBridgePool
impl JmsBridgePool
pub fn from_config(pool_config: JmsPoolConfig) -> Result<Self, CamelError>
Sourcepub fn resolve_broker_name(
&self,
name: Option<&str>,
) -> Result<String, CamelError>
pub fn resolve_broker_name( &self, name: Option<&str>, ) -> Result<String, CamelError>
Resolve broker name from the URI broker= param.
- If
Some(name)→ validate it exists in config and return it. - If
Noneand exactly one broker is configured → use it implicitly. - If
Noneand multiple brokers are configured → error asking for?broker=. - If
Noneand no brokers are configured → error asking to declare brokers.
Sourcepub fn resolve_broker_type(&self, scheme: &str, broker_name: &str) -> BrokerType
pub fn resolve_broker_type(&self, scheme: &str, broker_name: &str) -> BrokerType
Resolve broker type: activemq/artemis schemes hard-override config type; jms uses config.
Sourcepub async fn get_or_create_slot(
&self,
broker_name: &str,
) -> Result<Arc<BridgeSlot>, CamelError>
pub async fn get_or_create_slot( &self, broker_name: &str, ) -> Result<Arc<BridgeSlot>, CamelError>
Get or create a BridgeSlot for the given broker name. If the slot doesn’t exist, starts the bridge process and spawns the health monitor.
Sourcepub fn restart_slot(&self, broker_name: &str)
pub fn restart_slot(&self, broker_name: &str)
Signal a slot to restart (called by producers on transport errors).
Sourcepub async fn refresh_slot_channel(
&self,
broker_name: &str,
) -> Result<(), CamelError>
pub async fn refresh_slot_channel( &self, broker_name: &str, ) -> Result<(), CamelError>
Recreate the tonic channel for an existing running bridge process.
Useful when a channel becomes stale after transport-level failures while the underlying bridge process is still alive.
pub fn begin_shutdown(&self)
Sourcepub async fn shutdown(&self) -> Result<(), CamelError>
pub async fn shutdown(&self) -> Result<(), CamelError>
Shutdown all slots: stop all bridge processes and await health monitors.